@@ -1,17 +1,17 @@
 #include "OPF.h"
 #include <stdio.h>
 
-static int main(int argc, char **argv)
+void c_opf_fold(int *argc, char **argv)
 {
 	errorOccurred = 0;
 
-	if (argc != 4)
+	if (*argc != 4)
 	{
 		REprintf("\nusage opf_fold <P1> <P2> <P3>");
 		REprintf("\nP1: input dataset in the OPF file format");
 		REprintf("\nP2: k");
 		REprintf("\nP3: normalize features? 1 - Yes  0 - No\n\n");
-		return 0;
+		return;
 	}
 	Subgraph *g = NULL, **fold = NULL;
 	int k = atoi(argv[2]), i, op = atoi(argv[3]);
@@ -19,13 +19,13 @@ static int main(int argc, char **argv)
 
 	Rprintf("\nReading data set ...");
 	
-	g = ReadSubgraph(argv[1]); if(errorOccurred) return 0;
+	g = ReadSubgraph(argv[1]); if(errorOccurred) return;
 	Rprintf(" OK");
 	
 
 	Rprintf("\nCreating %d folds ...", k);
 	
-	fold = opf_kFoldSubgraph(g, k); if(errorOccurred) return 0;
+	fold = opf_kFoldSubgraph(g, k); if(errorOccurred) return;
 	Rprintf(" OK\n");
 
 	for (i = 0; i < k; i++)
@@ -34,9 +34,9 @@ static int main(int argc, char **argv)
 			
 		sprintf(fileName, "%s%d",argv[1],(i+1));
 		if (op){
-			opf_NormalizeFeatures(fold[i]); if(errorOccurred) return 0;
+			opf_NormalizeFeatures(fold[i]); if(errorOccurred) return;
 		}
-		WriteSubgraph(fold[i], fileName); if(errorOccurred) return 0;
+		WriteSubgraph(fold[i], fileName); if(errorOccurred) return;
 	}
 	Rprintf(" OK\n");
 
@@ -46,11 +46,4 @@ static int main(int argc, char **argv)
 		DestroySubgraph(&fold[i]);
 	free(fold);
 	Rprintf(" OK\n");
-
-	return 0;
-}
-
-void c_opf_fold(int *argc, char **argv){
-	main(*argc,argv);
-	
 }
